Class: Google::Apis::BinaryauthorizationV1::SigstoreAuthority
- Inherits:
-
Object
- Object
- Google::Apis::BinaryauthorizationV1::SigstoreAuthority
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/binaryauthorization_v1/classes.rb,
lib/google/apis/binaryauthorization_v1/representations.rb,
lib/google/apis/binaryauthorization_v1/representations.rb
Overview
A Sigstore authority, used to verify signatures that are created by Sigstore. An authority is analogous to an attestation authenticator, verifying that a signature is valid or invalid.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Optional.
-
#public_key_set ⇒ Google::Apis::BinaryauthorizationV1::SigstorePublicKeySet
A bundle of Sigstore public keys, used to verify Sigstore signatures.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SigstoreAuthority
constructor
A new instance of SigstoreAuthority.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SigstoreAuthority
Returns a new instance of SigstoreAuthority.
1487 1488 1489 |
# File 'lib/google/apis/binaryauthorization_v1/classes.rb', line 1487 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Optional. A user-provided name for this SigstoreAuthority. This field has no
effect on the policy evaluation behavior except to improve readability of
messages in evaluation results.
Corresponds to the JSON property displayName
1478 1479 1480 |
# File 'lib/google/apis/binaryauthorization_v1/classes.rb', line 1478 def display_name @display_name end |
#public_key_set ⇒ Google::Apis::BinaryauthorizationV1::SigstorePublicKeySet
A bundle of Sigstore public keys, used to verify Sigstore signatures. A
signature is authenticated by a SigstorePublicKeySet if any of the keys
verify it.
Corresponds to the JSON property publicKeySet
1485 1486 1487 |
# File 'lib/google/apis/binaryauthorization_v1/classes.rb', line 1485 def public_key_set @public_key_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1492 1493 1494 1495 |
# File 'lib/google/apis/binaryauthorization_v1/classes.rb', line 1492 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @public_key_set = args[:public_key_set] if args.key?(:public_key_set) end |