Class: Google::Apis::BinaryauthorizationV1::SlsaCheck
- Inherits:
-
Object
- Object
- Google::Apis::BinaryauthorizationV1::SlsaCheck
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/binaryauthorization_v1/classes.rb,
lib/google/apis/binaryauthorization_v1/representations.rb,
lib/google/apis/binaryauthorization_v1/representations.rb
Overview
A SLSA provenance attestation check, which ensures that images are built by a trusted builder using source code from its trusted repositories only.
Instance Attribute Summary collapse
-
#rules ⇒ Array<Google::Apis::BinaryauthorizationV1::VerificationRule>
Specifies a list of verification rules for the SLSA attestations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SlsaCheck
constructor
A new instance of SlsaCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SlsaCheck
Returns a new instance of SlsaCheck.
1611 1612 1613 |
# File 'lib/google/apis/binaryauthorization_v1/classes.rb', line 1611 def initialize(**args) update!(**args) end |
Instance Attribute Details
#rules ⇒ Array<Google::Apis::BinaryauthorizationV1::VerificationRule>
Specifies a list of verification rules for the SLSA attestations. An image is
considered compliant with the SlsaCheck if any of the rules are satisfied.
Corresponds to the JSON property rules
1609 1610 1611 |
# File 'lib/google/apis/binaryauthorization_v1/classes.rb', line 1609 def rules @rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1616 1617 1618 |
# File 'lib/google/apis/binaryauthorization_v1/classes.rb', line 1616 def update!(**args) @rules = args[:rules] if args.key?(:rules) end |