Class: Google::Apis::BinaryauthorizationV1::ValidateAttestationOccurrenceRequest
- Inherits:
-
Object
- Object
- Google::Apis::BinaryauthorizationV1::ValidateAttestationOccurrenceRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/binaryauthorization_v1/classes.rb,
lib/google/apis/binaryauthorization_v1/representations.rb,
lib/google/apis/binaryauthorization_v1/representations.rb
Overview
Request message for ValidationHelperV1.ValidateAttestationOccurrence.
Instance Attribute Summary collapse
-
#attestation ⇒ Google::Apis::BinaryauthorizationV1::AttestationOccurrence
Occurrence that represents a single "attestation".
-
#occurrence_note ⇒ String
Required.
-
#occurrence_resource_uri ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ValidateAttestationOccurrenceRequest
constructor
A new instance of ValidateAttestationOccurrenceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ValidateAttestationOccurrenceRequest
Returns a new instance of ValidateAttestationOccurrenceRequest.
1771 1772 1773 |
# File 'lib/google/apis/binaryauthorization_v1/classes.rb', line 1771 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attestation ⇒ Google::Apis::BinaryauthorizationV1::AttestationOccurrence
Occurrence that represents a single "attestation". The authenticity of an
attestation can be verified using the attached signature. If the verifier
trusts the public key of the signer, then verifying the signature is
sufficient to establish trust. In this circumstance, the authority to which
this attestation is attached is primarily useful for lookup (how to find this
attestation if you already know the authority and artifact to be verified) and
intent (for which authority this attestation was intended to sign.
Corresponds to the JSON property attestation
1757 1758 1759 |
# File 'lib/google/apis/binaryauthorization_v1/classes.rb', line 1757 def attestation @attestation end |
#occurrence_note ⇒ String
Required. The resource name of the Note to which the containing Occurrence is
associated.
Corresponds to the JSON property occurrenceNote
1763 1764 1765 |
# File 'lib/google/apis/binaryauthorization_v1/classes.rb', line 1763 def occurrence_note @occurrence_note end |
#occurrence_resource_uri ⇒ String
Required. The URI of the artifact (e.g. container image) that is the subject
of the containing Occurrence.
Corresponds to the JSON property occurrenceResourceUri
1769 1770 1771 |
# File 'lib/google/apis/binaryauthorization_v1/classes.rb', line 1769 def occurrence_resource_uri @occurrence_resource_uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1776 1777 1778 1779 1780 |
# File 'lib/google/apis/binaryauthorization_v1/classes.rb', line 1776 def update!(**args) @attestation = args[:attestation] if args.key?(:attestation) @occurrence_note = args[:occurrence_note] if args.key?(:occurrence_note) @occurrence_resource_uri = args[:occurrence_resource_uri] if args.key?(:occurrence_resource_uri) end |